;;
;; This is a cushion module to use R7RS (scheme r5rs) from Gauche
;;
(define-module scheme.r5rs (use r7rs-setup))
